==> Ver%203.0.0.zip: Ver 3.0.0/src/jp/mosp/payroll/bonus/dto/BonusListDto.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.payroll.bonus.dto;

import jp.mosp.common.common.BaseDto;

/**
 * ^f[^ꗗ̃R[hێB<br><br>
 */
public class BonusListDto extends BaseDto {

	private static final long serialVersionUID = -5928119945964049178L;
	
//	 tB[h
	private String kcode        = "";	// ЈR[h
	private String simei        = "";	// 
	private String furigana     = "";	// ӂ肪
	private String scode        = "";	// R[h
	private String ycode        = "";	// ER[h
	private String jcode        = "";	// ƏR[h
	
	private long   paymentTotal = 0 ;	// xz
	private String officeName   = "";	// Ə
	private String sectionName  = "";	// 
	private String positionName = "";	// E
	
	/**
	 * xz擾B
	 * @return xz
	 */
	public long getPaymentTotal() {
		return paymentTotal;
	}
	
	/**
	 * xzݒ肷B
	 * @param paymentTotal ݒ肷鍷xz
	 */
	public void setPaymentTotal(long paymentTotal) {
		this.paymentTotal = paymentTotal;
	}
	
	/**
	 * Ə擾B
	 * @return Ə
	 */
	public String getOfficeName() {
		return officeName;
	}

	/**
	 * Əݒ肷B
	 * @param officeName ݒ肷鎖Ə
	 */
	public void setOfficeName(String officeName) {
		this.officeName = officeName;
	}

	/**
	 * E擾B
	 * @return E
	 */
	public String getPositionName() {
		return positionName;
	}

	/**
	 * Eݒ肷B
	 * @param positionName ݒ肷E
	 */
	public void setPositionName(String positionName) {
		this.positionName = positionName;
	}

	/**
	 * 擾B
	 * @return 
	 */
	public String getSectionName() {
		return sectionName;
	}

	/**
	 * ݒ肷B
	 * @param sectionName ݒ肷鏊
	 */
	public void setSectionName(String sectionName) {
		this.sectionName = sectionName;
	}
	
	// ANZT\bh
	public String  getKCode () 		{ return kcode 		; }		//ЈR[h
	public String  getSimei () 		{ return simei 		; }		//
	public String  getFurigana ()  	{ return furigana 	; }		//ӂ肪
	public String  getSCode () 		{ return scode 		; }		//R[h
	public String  getYCode () 		{ return ycode 		; }		//ER[h
	public String  getJCode () 		{ return jcode 		; }		//ƏR[h

	public void setKCode 		(String  KCode 		) 		{ this.kcode 	 	= KCode 	; }		//ЈR[h
	public void setSimei 		(String  Simei 		) 		{ this.simei  		= Simei 	; }		//
	public void setFurigana 	(String  Furigana 	) 		{ this.furigana  	= Furigana 	; }		//ӂ肪
	public void setSCode 		(String  SCode 		) 		{ this.scode  		= SCode 	; }		//R[h
	public void setYCode 		(String  YCode 		) 		{ this.ycode  		= YCode 	; }		//ER[h
	public void setJCode 		(String  JCode 		) 		{ this.jcode  		= JCode 	; }		//ƏR[h

}

==> Ver%203.1.1.zip: Ver 3.1.1/src/jp/mosp/payroll/bonus/dto/BonusListDto.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.payroll.bonus.dto;

import jp.mosp.common.common.BaseDto;

/**
 * ^f[^ꗗ̃R[hێB<br><br>
 */
public class BonusListDto extends BaseDto {

	private static final long serialVersionUID = -5928119945964049178L;
	
//	 tB[h
	private String kcode        = "";	// ЈR[h
	private String simei        = "";	// 
	private String furigana     = "";	// ӂ肪
	private String scode        = "";	// R[h
	private String ycode        = "";	// ER[h
	private String jcode        = "";	// ƏR[h
	
	private int   paymentTotal = 0 ;	// xz
	private String officeName   = "";	// Ə
	private String sectionName  = "";	// 
	private String positionName = "";	// E
	
	/**
	 * xz擾B
	 * @return xz
	 */
	public int getPaymentTotal() {
		return paymentTotal;
	}
	
	/**
	 * xzݒ肷B
	 * @param paymentTotal ݒ肷鍷xz
	 */
	public void setPaymentTotal(int paymentTotal) {
		this.paymentTotal = paymentTotal;
	}
	
	/**
	 * Ə擾B
	 * @return Ə
	 */
	public String getOfficeName() {
		return officeName;
	}

	/**
	 * Əݒ肷B
	 * @param officeName ݒ肷鎖Ə
	 */
	public void setOfficeName(String officeName) {
		this.officeName = officeName;
	}

	/**
	 * E擾B
	 * @return E
	 */
	public String getPositionName() {
		return positionName;
	}

	/**
	 * Eݒ肷B
	 * @param positionName ݒ肷E
	 */
	public void setPositionName(String positionName) {
		this.positionName = positionName;
	}

	/**
	 * 擾B
	 * @return 
	 */
	public String getSectionName() {
		return sectionName;
	}

	/**
	 * ݒ肷B
	 * @param sectionName ݒ肷鏊
	 */
	public void setSectionName(String sectionName) {
		this.sectionName = sectionName;
	}
	
	// ANZT\bh
	public String  getKCode () 		{ return kcode 		; }		//ЈR[h
	public String  getSimei () 		{ return simei 		; }		//
	public String  getFurigana ()  	{ return furigana 	; }		//ӂ肪
	public String  getSCode () 		{ return scode 		; }		//R[h
	public String  getYCode () 		{ return ycode 		; }		//ER[h
	public String  getJCode () 		{ return jcode 		; }		//ƏR[h

	public void setKCode 		(String  KCode 		) 		{ this.kcode 	 	= KCode 	; }		//ЈR[h
	public void setSimei 		(String  Simei 		) 		{ this.simei  		= Simei 	; }		//
	public void setFurigana 	(String  Furigana 	) 		{ this.furigana  	= Furigana 	; }		//ӂ肪
	public void setSCode 		(String  SCode 		) 		{ this.scode  		= SCode 	; }		//R[h
	public void setYCode 		(String  YCode 		) 		{ this.ycode  		= YCode 	; }		//ER[h
	public void setJCode 		(String  JCode 		) 		{ this.jcode  		= JCode 	; }		//ƏR[h

}
